@@ -17,15 +17,16 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "contextmanager.moc"
+#include "contextmanager.h"
+#include "contextmanager.h"
 
 // Qt
 #include <QItemSelectionModel>
 #include <QTimer>
 #include <QUndoGroup>
+#include <QUrl>
 
 // KDE
-#include <KDebug>
 #include <KDirLister>
 #include <KFileItem>
 
@@ -41,10 +42,10 @@ struct ContextManagerPrivate
 {
     SortedDirModel* mDirModel;
     QItemSelectionModel* mSelectionModel;
-    KUrl mCurrentDirUrl;
-    KUrl mCurrentUrl;
+    QUrl mCurrentDirUrl;
+    QUrl mCurrentUrl;
 
-    KUrl mUrlToSelect;
+    QUrl mUrlToSelect;
 
     bool mSelectedFileItemListNeedsUpdate;
     QSet<QByteArray> mQueuedSignals;
@@ -73,7 +74,7 @@ struct ContextManagerPrivate
         // the list if we are viewing a non-browsable url, for example
         // using http protocol)
         if (mSelectedFileItemList.isEmpty() && mCurrentUrl.isValid()) {
-            KFileItem item(KFileItem::Unknown, KFileItem::Unknown, mCurrentUrl);
+            KFileItem item(mCurrentUrl);
             mSelectedFileItemList << item;
         }
 
@@ -88,12 +89,10 @@ ContextManager::ContextManager(SortedDirModel* dirModel, QObject* parent)
     d->mQueuedSignalsTimer = new QTimer(this);
     d->mQueuedSignalsTimer->setInterval(100);
     d->mQueuedSignalsTimer->setSingleShot(true);
-    connect(d->mQueuedSignalsTimer, SIGNAL(timeout()),
-            SLOT(emitQueuedSignals()));
+    connect(d->mQueuedSignalsTimer, &QTimer::timeout, this, &ContextManager::emitQueuedSignals);
 
     d->mDirModel = dirModel;
-    connect(d->mDirModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            SLOT(slotDirModelDataChanged(QModelIndex,QModelIndex)));
+    connect(d->mDirModel, &SortedDirModel::dataChanged, this, &ContextManager::slotDirModelDataChanged);
 
     /* HACK! In extended-selection mode, when the current index is removed,
      * QItemSelectionModel selects the previous index if there is one, if not it
@@ -110,21 +109,17 @@ ContextManager::ContextManager(SortedDirModel* dirModel, QObject* parent)
      * doing so ensures QItemSelectionModel cannot be connected to the
      * mDirModel.rowsAboutToBeRemoved() signal before us.
      */
-    connect(d->mDirModel, SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-            SLOT(slotRowsAboutToBeRemoved(QModelIndex,int,int)));
+    connect(d->mDirModel, &SortedDirModel::rowsAboutToBeRemoved, this, &ContextManager::slotRowsAboutToBeRemoved);
 
-    connect(d->mDirModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            SLOT(slotRowsInserted()));
+    connect(d->mDirModel, &SortedDirModel::rowsInserted, this, &ContextManager::slotRowsInserted);
 
-    connect(d->mDirModel->dirLister(), SIGNAL(redirection(KUrl)),
-            SLOT(slotDirListerRedirection(KUrl)));
+    connect(d->mDirModel->dirLister(), SIGNAL(redirection(QUrl)),
+            SLOT(slotDirListerRedirection(QUrl)));
 
     d->mSelectionModel = new QItemSelectionModel(d->mDirModel);
 
-    connect(d->mSelectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-            SLOT(slotSelectionChanged()));
-    connect(d->mSelectionModel, SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            SLOT(slotCurrentChanged(QModelIndex)));
+    connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged, this, &ContextManager::slotSelectionChanged);
+    connect(d->mSelectionModel, &QItemSelectionModel::currentChanged, this, &ContextManager::slotCurrentChanged);
 
     d->mSelectedFileItemListNeedsUpdate = false;
 }
@@ -139,7 +134,7 @@ QItemSelectionModel* ContextManager::selectionModel() const
     return d->mSelectionModel;
 }
 
-void ContextManager::setCurrentUrl(const KUrl& currentUrl)
+void ContextManager::setCurrentUrl(const QUrl &currentUrl)
 {
     if (d->mCurrentUrl == currentUrl) {
         return;
@@ -162,9 +157,9 @@ KFileItemList ContextManager::selectedFileItemList() const
     return d->mSelectedFileItemList;
 }
 
-void ContextManager::setCurrentDirUrl(const KUrl& url)
+void ContextManager::setCurrentDirUrl(const QUrl &url)
 {
-    if (url.equals(d->mCurrentDirUrl, KUrl::CompareWithoutTrailingSlash)) {
+    if (url == d->mCurrentDirUrl) {
         return;
     }
     d->mCurrentDirUrl = url;
@@ -174,12 +169,12 @@ void ContextManager::setCurrentDirUrl(const KUrl& url)
     currentDirUrlChanged(url);
 }
 
-KUrl ContextManager::currentDirUrl() const
+QUrl ContextManager::currentDirUrl() const
 {
     return d->mCurrentDirUrl;
 }
 
-KUrl ContextManager::currentUrl() const
+QUrl ContextManager::currentUrl() const
 {
     return d->mCurrentUrl;
 }
@@ -227,14 +222,14 @@ void ContextManager::slotSelectionChanged()
 {
     d->mSelectedFileItemListNeedsUpdate = true;
     if (!d->mSelectionModel->hasSelection()) {
-        setCurrentUrl(KUrl());
+        setCurrentUrl(QUrl());
     }
     d->queueSignal("selectionChanged");
 }
 
 void Gwenview::ContextManager::slotCurrentChanged(const QModelIndex& index)
 {
-    KUrl url = d->mDirModel->urlForIndex(index);
+    QUrl url = d->mDirModel->urlForIndex(index);
     setCurrentUrl(url);
 }
 
@@ -271,12 +266,12 @@ bool ContextManager::currentUrlIsRasterImage() const
     return MimeTypeUtils::urlKind(currentUrl()) == MimeTypeUtils::KIND_RASTER_IMAGE;
 }
 
-KUrl ContextManager::urlToSelect() const
+QUrl ContextManager::urlToSelect() const
 {
     return d->mUrlToSelect;
 }
 
-void ContextManager::setUrlToSelect(const KUrl& url)
+void ContextManager::setUrlToSelect(const QUrl &url)
 {
     GV_RETURN_IF_FAIL(url.isValid());
     d->mUrlToSelect = url;
@@ -304,11 +299,11 @@ void ContextManager::selectUrlToSelect()
     QModelIndex index = d->mDirModel->indexForUrl(d->mUrlToSelect);
     if (index.isValid()) {
         d->mSelectionModel->setCurrentIndex(index, QItemSelectionModel::ClearAndSelect);
-        d->mUrlToSelect = KUrl();
+        d->mUrlToSelect = QUrl();
     }
 }
 
-void ContextManager::slotDirListerRedirection(const KUrl& newUrl)
+void ContextManager::slotDirListerRedirection(const QUrl &newUrl)
 {
     setCurrentDirUrl(newUrl);
 }
