@@ -17,21 +17,19 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
-#include "document.moc"
-#include "document_p.moc"
+#include "document.h"
+#include "document_p.h"
 
 // Qt
 #include <QApplication>
 #include <QImage>
-#include <QQueue>
 #include <QUndoStack>
+#include <QUrl>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KFileItem>
+#include <KLocalizedString>
 #include <KJobUiDelegate>
-#include <KLocale>
-#include <KUrl>
 
 // Local
 #include "documentjob.h"
@@ -49,7 +47,7 @@ namespace Gwenview
 #undef LOG
 //#define ENABLE_LOG
 #ifdef ENABLE_LOG
-#define LOG(x) kDebug() << x
+#define LOG(x) //qDebug() << x
 #else
 #define LOG(x) ;
 #endif
@@ -131,7 +129,7 @@ void DocumentPrivate::downSampleImage(int invertedZoom)
         mDownSampledImageMap[invertedZoom] = mImage;
     }
     q->downSampledImageReady();
-};
+}
 
 //- DownSamplingJob ---------------------------------------
 void DownSamplingJob::doStart()
@@ -148,7 +146,7 @@ qreal Document::maxDownSampledZoom()
     return 0.5;
 }
 
-Document::Document(const KUrl& url)
+Document::Document(const QUrl &url)
 : QObject()
 , d(new DocumentPrivate)
 {
@@ -266,7 +264,7 @@ void Document::setImageInternal(const QImage& image)
     setSize(d->mImage.size());
 }
 
-KUrl Document::url() const
+QUrl Document::url() const
 {
     return d->mUrl;
 }
@@ -298,18 +296,18 @@ void Document::waitUntilLoaded()
     }
 }
 
-DocumentJob* Document::save(const KUrl& url, const QByteArray& format)
+DocumentJob* Document::save(const QUrl &url, const QByteArray& format)
 {
     waitUntilLoaded();
     DocumentJob* job = d->mImpl->save(url, format);
     if (!job) {
-        kWarning() << "Implementation does not support saving!";
+        qWarning() << "Implementation does not support saving!";
         setErrorString(i18nc("@info", "Gwenview cannot save this kind of documents."));
         return 0;
     }
     job->setProperty("oldUrl", d->mUrl);
     job->setProperty("newUrl", url);
-    connect(job, SIGNAL(result(KJob*)), SLOT(slotSaveResult(KJob*)));
+    connect(job, &DocumentJob::result, this, &Document::slotSaveResult);
     enqueueJob(job);
     return job;
 }
@@ -433,14 +431,14 @@ void Document::startLoadingFullImage()
     } else if (state == Loaded) {
         return;
     } else if (state == LoadingFailed) {
-        kWarning() << "Can't load full image: loading has already failed";
+        qWarning() << "Can't load full image: loading has already failed";
     }
 }
 
 bool Document::prepareDownSampledImageForZoom(qreal zoom)
 {
     if (zoom >= maxDownSampledZoom()) {
-        kWarning() << "No need to call prepareDownSampledImageForZoom if zoom >= " << maxDownSampledZoom();
+        qWarning() << "No need to call prepareDownSampledImageForZoom if zoom >= " << maxDownSampledZoom();
         return true;
     }
 
@@ -452,7 +450,7 @@ bool Document::prepareDownSampledImageForZoom(qreal zoom)
 
     LOG("downSampledImageForZoom=" << zoom << "invertedZoom=" << invertedZoom << "not ready");
     if (loadingState() == LoadingFailed) {
-        kWarning() << "Image has failed to load, not doing anything";
+        qWarning() << "Image has failed to load, not doing anything";
         return false;
     } else if (loadingState() == Loaded) {
         d->scheduleImageDownSampling(invertedZoom);
@@ -521,8 +519,7 @@ void Document::enqueueJob(DocumentJob* job)
 {
     LOG("job=" << job);
     job->setDocument(Ptr(this));
-    connect(job, SIGNAL(finished(KJob*)),
-            SLOT(slotJobFinished(KJob*)));
+    connect(job, &LoadingJob::finished, this, &Document::slotJobFinished);
     if (d->mCurrentJob) {
         d->mJobQueue.enqueue(job);
     } else {
