@@ -19,13 +19,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "thumbnailslider.moc"
+#include "thumbnailslider.h"
 
 // Local
 #include <thumbnailview/thumbnailview.h>
 
 // Qt
-#include <QSlider>
 #include <QToolTip>
 
 // KDE
